@@ -6,7 +6,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.46';
+our $VERSION = '0.47';
 
 use Courriel::Headers;
 use Courriel::Helpers qw( unique_boundary );
@@ -532,7 +532,7 @@ Courriel - High level email parsing and manipulation
 
 =head1 VERSION
 
-version 0.46
+version 0.47
 
 =head1 SYNOPSIS
 
@@ -789,7 +789,7 @@ through the web interface at L<http://rt.cpan.org>.  I will be notified, and
 then you'll automatically be notified of progress on your bug as I make
 changes.
 
-Bugs may be submitted at L<http://rt.cpan.org/Public/Dist/Display.html?Name=Courriel> or via email to L<bug-courriel@rt.cpan.org|mailto:bug-courriel@rt.cpan.org>.
+Bugs may be submitted at L<https://github.com/houseabsolute/Courriel/issues>.
 
 I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
 
