@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.46';
+our $VERSION = '0.47';
 
 use Courriel::Helpers qw( fold_header );
 use Courriel::Types qw( NonEmptyStr Str Streamable );
@@ -255,7 +255,7 @@ Courriel::Header - A single header's name and value
 
 =head1 VERSION
 
-version 0.46
+version 0.47
 
 =head1 SYNOPSIS
 
@@ -306,7 +306,7 @@ This class does the C<Courriel::Role::Streams> role.
 
 =head1 SUPPORT
 
-Bugs may be submitted at L<http://rt.cpan.org/Public/Dist/Display.html?Name=Courriel> or via email to L<bug-courriel@rt.cpan.org|mailto:bug-courriel@rt.cpan.org>.
+Bugs may be submitted at L<https://github.com/houseabsolute/Courriel/issues>.
 
 I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
 
